Crate kcr_apps_kubeedge_io

Crate kcr_apps_kubeedge_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apps.kubeedge.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

apps.kubeedge.io/v1alpha1

  • EdgeApplication
  • NodeGroup

Modules

v1alpha1